/*
   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   SLEPc - Scalable Library for Eigenvalue Problem Computations
   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain

   This file is part of SLEPc.
   SLEPc is distributed under a 2-clause BSD license (see LICENSE).
   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
*/

#if !defined(SLEPCRGTYPES_H)
#define SLEPCRGTYPES_H

/*S
   RG - Region of the complex plane.

   Level: beginner

.seealso: RGCreate()
S*/
typedef struct _p_RG* RG;

#endif
